@@ -62,7 +62,7 @@ if [[ ! -e "${IMGROOT}/efi/boot/bootx64.efi" ]]; then
 	
 	LOOP_DEVICE2="$(losetup --show --find "${IMGROOT}/efi/grub2/grub2_efi.bin")"
 	mount -o ro -t vfat "${LOOP_DEVICE2}" "${TMPDIR2}"
-	cp "${TMPDIR2}/bootx64.efi" "${IMGROOT}/efi/boot/bootx64.efi"
+	cp -f "${TMPDIR2}/bootx64.efi" "${IMGROOT}/efi/boot/bootx64.efi"
 	
 	umount "${TMPDIR2}"
 	losetup --detach "${LOOP_DEVICE2}"
@@ -70,10 +70,10 @@ if [[ ! -e "${IMGROOT}/efi/boot/bootx64.efi" ]]; then
 	rm -rf "${TMPDIR2}"
 fi
 
-cp -r "${IMGROOT}"/* "${TMPDIR}"
+cp -rf "${IMGROOT}"/* "${TMPDIR}"
 
 rm -f "${TMPDIR}/boot/syslinux"/*.{com,bin,c32} || true
-cp "/usr/lib/syslinux"/*.{com,bin,c32} "${TMPDIR}/boot/syslinux/"
+cp -f "/usr/lib/syslinux"/*.{com,bin,c32} "${TMPDIR}/boot/syslinux/"
 
 # unmount filesystem
 umount "${TMPDIR}"
